@@ -27,11 +27,12 @@ if (freeEdges["top"] == true) {
 
 panel.height = gridUnit * 1.7
 
-var kickoff = panel.addWidget("org.kde.plasma.kickoff")
-kickoff.currentConfigGroup = ["Shortcuts"]
-kickoff.writeConfig("global", "Alt+F1")
-kickoff.currentConfigGroup = ["Configuration/General"]
-kickoff.writeConfig("showAppsByName", "true")
+var kicker = panel.addWidget("org.kde.plasma.kicker")
+kicker.writeConfig("favoriteApps", "preferred://browser,org.kde.discover.desktop,systemsettings.desktop,org.kde.dolphin.desktop,org.kde.kate.desktop,patchance.desktop,ardour.desktop,com.obsproject.Studio.desktop,org.kde.krita.desktop,gimp.desktop,org.kde.kdenlive.desktop,org.kde.digikam.desktop,org.darktable.darktable.desktop")
+kicker.writeConfig("showAppsByName", "true")
+kicker.currentConfigGroup = ["Shortcuts"]
+kicker.writeConfig("global", "Alt+F1")
+
 
 //panel.addWidget("org.kde.plasma.showActivityManager")
 panel.addWidget("org.kde.plasma.pager")
@@ -95,4 +96,3 @@ if (langIds.indexOf(languageId) != -1) {
 panel.addWidget("org.kde.plasma.systemtray")
 panel.addWidget("org.kde.plasma.digitalclock")
 panel.addWidget("org.kde.plasma.minimizeall")
-
